@@ -8,11 +8,12 @@ similarity-, normalisation- functions and explanation methods in Quantus."""
 # Quantus project URL: <https://github.com/understandable-machine-intelligence-lab/Quantus>.
 
 from typing import List, Dict
-from ..metrics import *
-from .normalise_func import *
-from .perturb_func import *
-from .similarity_func import *
-from .loss_func import *
+
+from quantus.functions.loss_func import *
+from quantus.functions.normalise_func import *
+from quantus.functions.perturb_func import *
+from quantus.functions.similarity_func import *
+from quantus.metrics import *
 
 
 AVAILABLE_METRICS = {
@@ -99,7 +100,7 @@ AVAILABLE_NORMALISATION_FUNCTIONS = {
 }
 
 
-AVAILABLE_XAI_METHODS = {
+AVAILABLE_XAI_METHODS = [
     "Gradient",
     "Saliency",
     "GradientShap",
@@ -111,7 +112,7 @@ AVAILABLE_XAI_METHODS = {
     "Control Var. Sobel Filter",
     "Control Var. Constant",
     "Control Var. Random Uniform",
-}
+]
 
 
 def available_categories() -> List[str]:
@@ -126,7 +127,7 @@ def available_categories() -> List[str]:
     return [c for c in AVAILABLE_METRICS.keys()]
 
 
-def available_metrics() -> Dict[str, str]:
+def available_metrics() -> Dict[str, List[str]]:
     """
     Retrieve the available metrics in Quantus.
 
@@ -147,7 +148,7 @@ def available_methods() -> List[str]:
     List[str]
         With the available explanation methods in Quantus.
     """
-    return [c for c in AVAILABLE_XAI_METHODS.keys()]
+    return [c for c in AVAILABLE_XAI_METHODS]
 
 
 def available_perturbation_functions() -> List[str]:
