@@ -253,7 +253,7 @@ def infer_channel_first(x: np.array) -> bool:
         False if input shape is (nr_batch, img_width, img_height, nr_channels).
         An error is raised if the three last dimensions are equal.
     """
-    err_msg = "Ambiguous input shape. Cannot infer channel-first/channel-last order."
+    err_msg = "Ambiguous input shape. Cannot infer channel-first/channel-last order. Try setting the `channel_first` argument"
 
     if len(np.shape(x)) == 2:
         return True
@@ -962,10 +962,13 @@ def offset_coordinates(
     """
     x = indices // img_shape[2]
     y = indices % img_shape[2]
+
     x += offset[0]
     y += offset[1]
+
     valid = ~((x < 0) | (y < 0) | (x >= img_shape[1]) | (y >= img_shape[2]))
     off_coords = indices + offset[0] * img_shape[2] + offset[1]
+
     return off_coords[valid], valid
 
 
@@ -985,4 +988,4 @@ def calculate_auc(values: np.array, dx: int = 1):
     np.ndarray
         Definite integral of values.
     """
-    return np.trapz(np.array(values), dx=dx)
+    return np.trapz(np.array(values), dx=dx)
\ No newline at end of file
