@@ -55,6 +55,7 @@ class LocalLipschitzEstimate(BatchedPerturbationMetric):
         default_plot_func: Optional[Callable] = None,
         disable_warnings: bool = False,
         display_progressbar: bool = False,
+        return_nan_when_prediction_changes: bool = False,
         **kwargs,
     ):
         """
@@ -99,6 +100,8 @@ class LocalLipschitzEstimate(BatchedPerturbationMetric):
             Indicates whether the warnings are printed, default=False.
         display_progressbar: boolean
             Indicates whether a tqdm-progress-bar is printed, default=False.
+        return_nan_when_prediction_changes: boolean
+            When set to true, the metric will be evaluated to NaN if the prediction changes after the perturbation is applied.
         kwargs: optional
             Keyword arguments.
         """
@@ -142,6 +145,7 @@ class LocalLipschitzEstimate(BatchedPerturbationMetric):
         if norm_denominator is None:
             norm_denominator = distance_euclidean
         self.norm_denominator = norm_denominator
+        self.return_nan_when_prediction_changes = return_nan_when_prediction_changes
 
         # Asserts and warnings.
         if not self.disable_warnings:
@@ -315,6 +319,15 @@ class LocalLipschitzEstimate(BatchedPerturbationMetric):
                 **self.perturb_func_kwargs,
             )
 
+            changed_prediction_indices = (
+                np.argwhere(
+                    model.predict(x_batch).argmax(axis=-1)
+                    != model.predict(x_perturbed).argmax(axis=-1)
+                ).reshape(-1)
+                if self.return_nan_when_prediction_changes
+                else []
+            )
+
             x_input = model.shape_input(
                 x=x_perturbed,
                 shape=x_batch.shape,
@@ -347,6 +360,13 @@ class LocalLipschitzEstimate(BatchedPerturbationMetric):
 
             # Measure similarity for each instance separately.
             for instance_id in range(batch_size):
+                if (
+                    self.return_nan_when_prediction_changes
+                    and instance_id in changed_prediction_indices
+                ):
+                    similarities[instance_id, step_id] = np.nan
+                    continue
+
                 similarity = self.similarity_func(
                     a=a_batch[instance_id].flatten(),
                     b=a_perturbed[instance_id].flatten(),
@@ -356,8 +376,8 @@ class LocalLipschitzEstimate(BatchedPerturbationMetric):
                     norm_denominator=self.norm_denominator,
                 )
                 similarities[instance_id, step_id] = similarity
-
-        return np.nanmax(similarities, axis=1)
+        max_func = np.max if self.return_nan_when_prediction_changes else np.nanmax
+        return max_func(similarities, axis=1)
 
     def custom_preprocess(
         self,
