@@ -1,14 +1,13 @@
 from typing import Union
 
-import numpy as np
 import pytest
 from pytest_lazyfixture import lazy_fixture
 
-from ..fixtures import *
-from ...quantus.metrics import *
-from ...quantus.helpers import *
-from ...quantus.helpers.explanation_func import explain
+from quantus.functions.explanation_func import explain
+from quantus.helpers.model.model_interface import ModelInterface
+from quantus.metrics.complexity import Complexity, EffectiveComplexity, Sparseness
 
+from tests.fixtures import *
 
 @pytest.mark.complexity
 @pytest.mark.parametrize(
@@ -71,9 +70,7 @@ from ...quantus.helpers.explanation_func import explain
                     "disable_warnings": True,
                     "display_progressbar": False,
                 },
-                "call": {
-                    "explain_func": explain,
-                },
+                "call": {"explain_func": explain,},
             },
             {"max": 1.0, "min": 0.0},
         ),
@@ -86,9 +83,7 @@ from ...quantus.helpers.explanation_func import explain
                     "disable_warnings": True,
                     "display_progressbar": False,
                 },
-                "call": {
-                    "explain_func": explain,
-                },
+                "call": {"explain_func": explain,},
             },
             {"max": 1.0, "min": 0.0},
         ),
@@ -145,10 +140,7 @@ from ...quantus.helpers.explanation_func import explain
     ],
 )
 def test_sparseness(
-    model: ModelInterface,
-    data: dict,
-    params: dict,
-    expected: Union[float, dict, bool],
+    model: ModelInterface, data: dict, params: dict, expected: Union[float, dict, bool],
 ):
     init_params = params.get("init", {})
     call_params = params.get("call", {})
@@ -255,9 +247,7 @@ def test_sparseness(
                     "disable_warnings": True,
                     "display_progressbar": False,
                 },
-                "call": {
-                    "explain_func": explain,
-                },
+                "call": {"explain_func": explain,},
             },
             {"max": 1.0, "min": 0.0},
         ),
@@ -270,9 +260,7 @@ def test_sparseness(
                     "disable_warnings": True,
                     "display_progressbar": False,
                 },
-                "call": {
-                    "explain_func": explain,
-                },
+                "call": {"explain_func": explain,},
             },
             {"max": 1.0, "min": 0.0},
         ),
@@ -303,10 +291,7 @@ def test_sparseness(
     ],
 )
 def test_complexity(
-    model: ModelInterface,
-    data: dict,
-    params: dict,
-    expected: Union[float, dict, bool],
+    model: ModelInterface, data: dict, params: dict, expected: Union[float, dict, bool],
 ):
     init_params = params.get("init", {})
     call_params = params.get("call", {})
@@ -408,9 +393,7 @@ def test_complexity(
                     "disable_warnings": True,
                     "display_progressbar": False,
                 },
-                "call": {
-                    "explain_func": explain,
-                },
+                "call": {"explain_func": explain,},
             },
             {"max": 1.0, "min": 0.0},
         ),
@@ -423,9 +406,7 @@ def test_complexity(
                     "disable_warnings": True,
                     "display_progressbar": False,
                 },
-                "call": {
-                    "explain_func": explain,
-                },
+                "call": {"explain_func": explain,},
             },
             {"max": 1.0, "min": 0.0},
         ),
@@ -456,10 +437,7 @@ def test_complexity(
     ],
 )
 def test_effective_complexity(
-    model: ModelInterface,
-    data: dict,
-    params: dict,
-    expected: Union[float, dict, bool],
+    model: ModelInterface, data: dict, params: dict, expected: Union[float, dict, bool],
 ):
     init_params = params.get("init", {})
     call_params = params.get("call", {})
