@@ -1,14 +1,13 @@
 from typing import Union
 
-import numpy as np
 import pytest
 from pytest_lazyfixture import lazy_fixture
 
-from ..fixtures import *
-from ...quantus.metrics import *
-from ...quantus.helpers import *
-from ...quantus.helpers.explanation_func import explain
-from ...quantus.helpers.model_interface import ModelInterface
+from quantus.functions.explanation_func import explain
+from quantus.functions.similarity_func import correlation_spearman, correlation_pearson
+from quantus.helpers.model.model_interface import ModelInterface
+from quantus.metrics.randomisation import ModelParameterRandomisation, RandomLogit
+from tests.fixtures import *
 
 
 @pytest.mark.randomisation
@@ -28,9 +27,7 @@ from ...quantus.helpers.model_interface import ModelInterface
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {
-                        "method": "Saliency",
-                    },
+                    "explain_func_kwargs": {"method": "Saliency",},
                 },
             },
             {"min": -1.0, "max": 1.0},
@@ -48,9 +45,7 @@ from ...quantus.helpers.model_interface import ModelInterface
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {
-                        "method": "Saliency",
-                    },
+                    "explain_func_kwargs": {"method": "Saliency",},
                 },
             },
             {"min": -1.0, "max": 1.0},
@@ -68,9 +63,7 @@ from ...quantus.helpers.model_interface import ModelInterface
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {
-                        "method": "Saliency",
-                    },
+                    "explain_func_kwargs": {"method": "Saliency",},
                 },
             },
             {"min": -1.0, "max": 1.0},
@@ -88,9 +81,7 @@ from ...quantus.helpers.model_interface import ModelInterface
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {
-                        "method": "Saliency",
-                    },
+                    "explain_func_kwargs": {"method": "Saliency",},
                 },
             },
             {"min": -1.0, "max": 1.0},
@@ -108,9 +99,7 @@ from ...quantus.helpers.model_interface import ModelInterface
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {
-                        "method": "Gradient",
-                    },
+                    "explain_func_kwargs": {"method": "Gradient",},
                 },
             },
             {"min": -1.0, "max": 1.0},
@@ -129,9 +118,7 @@ from ...quantus.helpers.model_interface import ModelInterface
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {
-                        "method": "Gradient",
-                    },
+                    "explain_func_kwargs": {"method": "Gradient",},
                 },
             },
             {"exception": ValueError},
@@ -150,9 +137,7 @@ from ...quantus.helpers.model_interface import ModelInterface
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {
-                        "method": "Gradient",
-                    },
+                    "explain_func_kwargs": {"method": "Gradient",},
                 },
             },
             {"min": -1.0, "max": 1.0},
@@ -170,9 +155,7 @@ from ...quantus.helpers.model_interface import ModelInterface
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {
-                        "method": "Saliency",
-                    },
+                    "explain_func_kwargs": {"method": "Saliency",},
                 },
             },
             {"min": -1.0, "max": 1.0},
@@ -190,9 +173,7 @@ from ...quantus.helpers.model_interface import ModelInterface
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {
-                        "method": "Saliency",
-                    },
+                    "explain_func_kwargs": {"method": "Saliency",},
                 },
             },
             {"min": -1.0, "max": 1.0},
@@ -217,10 +198,7 @@ def test_model_parameter_randomisation(
         explain = call_params["explain_func"]
         explain_func_kwargs = call_params.get("explain_func_kwargs", {})
         a_batch = explain(
-            model=model,
-            inputs=x_batch,
-            targets=y_batch,
-            **explain_func_kwargs,
+            model=model, inputs=x_batch, targets=y_batch, **explain_func_kwargs,
         )
     elif "a_batch" in data:
         a_batch = data["a_batch"]
@@ -239,11 +217,7 @@ def test_model_parameter_randomisation(
         return
 
     scores_layers = ModelParameterRandomisation(**init_params)(
-        model=model,
-        x_batch=x_batch,
-        y_batch=y_batch,
-        a_batch=a_batch,
-        **call_params,
+        model=model, x_batch=x_batch, y_batch=y_batch, a_batch=a_batch, **call_params,
     )
     if isinstance(expected, float):
         assert all(
@@ -273,9 +247,7 @@ def test_model_parameter_randomisation(
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {
-                        "method": "Saliency",
-                    },
+                    "explain_func_kwargs": {"method": "Saliency",},
                 },
             },
             {"min": -1.0, "max": 1.0},
@@ -292,9 +264,7 @@ def test_model_parameter_randomisation(
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {
-                        "method": "Saliency",
-                    },
+                    "explain_func_kwargs": {"method": "Saliency",},
                 },
             },
             {"min": 0.0, "max": 1.0},
@@ -312,9 +282,7 @@ def test_model_parameter_randomisation(
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {
-                        "method": "Saliency",
-                    },
+                    "explain_func_kwargs": {"method": "Saliency",},
                 },
             },
             {"min": 0.0, "max": 1.0},
@@ -332,9 +300,7 @@ def test_model_parameter_randomisation(
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {
-                        "method": "Saliency",
-                    },
+                    "explain_func_kwargs": {"method": "Saliency",},
                 },
             },
             {"min": 0.0, "max": 1.0},
@@ -351,9 +317,7 @@ def test_model_parameter_randomisation(
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {
-                        "method": "Saliency",
-                    },
+                    "explain_func_kwargs": {"method": "Saliency",},
                 },
             },
             {"min": -1.0, "max": 1.0},
@@ -370,9 +334,7 @@ def test_model_parameter_randomisation(
                 },
                 "call": {
                     "explain_func": explain,
-                    "explain_func_kwargs": {
-                        "method": "Saliency",
-                    },
+                    "explain_func_kwargs": {"method": "Saliency",},
                 },
             },
             {"min": 0.0, "max": 1.0},
@@ -397,21 +359,14 @@ def test_random_logit(
         explain = call_params["explain_func"]
         explain_func_kwargs = call_params.get("explain_func_kwargs", {})
         a_batch = explain(
-            model=model,
-            inputs=x_batch,
-            targets=y_batch,
-            **explain_func_kwargs,
+            model=model, inputs=x_batch, targets=y_batch, **explain_func_kwargs,
         )
     elif "a_batch" in data:
         a_batch = data["a_batch"]
     else:
         a_batch = None
     scores = RandomLogit(**init_params)(
-        model=model,
-        x_batch=x_batch,
-        y_batch=y_batch,
-        a_batch=a_batch,
-        **call_params,
+        model=model, x_batch=x_batch, y_batch=y_batch, a_batch=a_batch, **call_params,
     )
 
     if isinstance(expected, float):
